@@ -5,7 +5,7 @@
 **
 ** Comments: Dump ARP / RARP header information
 **
-** $Id: arp.c,v 1.17 2001/05/18 21:54:16 mborella Exp $
+** $Id: arp.c,v 1.18 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -81,30 +81,29 @@ void dump_etherarp(packet_t *pkt)
    * Do minimal or not-so-minimal mode
    */
 
-  if (my_args->m && !my_args->n)
+  if (my_args->m)
     {
       display_minimal_ipv4((u_int8_t *) &etharp.target_protoaddr);
     }
   else
-    if (!my_args->n)
-      {
-	display("Sender Ether address", (u_int8_t *) &etharp.sender_hwaddr, 6, 
-		DISP_HEXCOLONS);
-	display_ipv4("Sender IP address",
-		     (u_int8_t *) &etharp.sender_protoaddr); 
-	display("Target Ether address", (u_int8_t *) &etharp.target_hwaddr, 6, 
-		DISP_HEXCOLONS);
-	display_ipv4("Target IP address",
-		     (u_int8_t *) &etharp.target_protoaddr); 
-      }
+    {
+      display("Sender Ether address", (u_int8_t *) &etharp.sender_hwaddr, 6, 
+	      DISP_HEXCOLONS);
+      display_ipv4("Sender IP address",
+		   (u_int8_t *) &etharp.sender_protoaddr); 
+      display("Target Ether address", (u_int8_t *) &etharp.target_hwaddr, 6, 
+	      DISP_HEXCOLONS);
+      display_ipv4("Target IP address",
+		   (u_int8_t *) &etharp.target_protoaddr); 
+    }
   
   /*
    * Some ARPs include Ethernet frame padding.  Check for that.  Note that we
    * must allow ARP frames to be 1500 bytes.  Some NICs seems to generate 
    * them as such.  Strange but true.
    */
-
- if (!my_args->m && !my_args->n)
+  
+ if (!my_args->m)
    {
      u_int8_t padding[ARP_PADDING_SIZE]; 
      int bytes;
@@ -132,6 +131,9 @@ void dump_arp(packet_t *pkt)
 {
   arp_header_t arp;
 
+  /* Set the layer */
+  set_layer(LAYER_DATALINK);
+
   /*
    * Stats accounting
    */
@@ -157,7 +159,7 @@ void dump_arp(packet_t *pkt)
    * Check for minimal mode first
    */
 
-  if (my_args->m && !my_args->n)
+  if (my_args->m)
     {
       display_minimal_string("| ARP ");
       switch(arp.opcode)
@@ -172,43 +174,42 @@ void dump_arp(packet_t *pkt)
 	}
     }
   else
-    if (!my_args->n)
-      {
-	/* 
-	 * Banner announcement 
-	 */
-	
-	display_header_banner("ARP Header");
-	
-	/*
-	 * Dump hardware type
-	 */
-	
-	display_strmap_hex("Hardware type", arp.hwaddr_format, 
-			   arp_hardware_map);
-	
-	/*
-	 * Dump protocol type
-	 */
-	
-	display_strmap_hex("Protocol type", arp.protoaddr_format, 
-			   ethertype_map);
-	
-	/* 
-	 * Dump hardware and protocol lengths
-	 */
-	
-	display("Hardware length", (u_int8_t *) &arp.hwaddr_length, 1, 
-		DISP_DEC);
-	display("Protocol length", (u_int8_t *) &arp.protoaddr_length, 1, 
-		DISP_DEC);
-	
-	/*
-	 * Now do the opcode
-	 */
-
-	display_strmap("Opcode", arp.opcode, arp_opcode_map);
-      }
+    {
+      /* 
+       * Banner announcement 
+       */
+      
+      display_header_banner("ARP Header");
+      
+      /*
+       * Dump hardware type
+       */
+      
+      display_strmap_hex("Hardware type", arp.hwaddr_format, 
+			 arp_hardware_map);
+      
+      /*
+       * Dump protocol type
+       */
+      
+      display_strmap_hex("Protocol type", arp.protoaddr_format, 
+			 ethertype_map);
+      
+      /* 
+       * Dump hardware and protocol lengths
+       */
+      
+      display("Hardware length", (u_int8_t *) &arp.hwaddr_length, 1, 
+	      DISP_DEC);
+      display("Protocol length", (u_int8_t *) &arp.protoaddr_length, 1, 
+	      DISP_DEC);
+      
+      /*
+       * Now do the opcode
+       */
+      
+      display_strmap("Opcode", arp.opcode, arp_opcode_map);
+    }
   
   /*
    * Check hardware type and layer 3 address format
