@@ -5,7 +5,7 @@
 **
 ** Comments: Dump ICMP information
 **
-** $Id: icmp.c,v 1.14 2001/04/02 17:41:01 mborella Exp $
+** $Id: icmp.c,v 1.15 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -277,6 +277,9 @@ void dump_icmp(packet_t *pkt)
   icmp_header_t icmp;
   char holder[64];
 
+  /* Set the layer */
+  set_layer(LAYER_NETWORK);
+
   /*
    * Stats accounting
    */
@@ -290,7 +293,7 @@ void dump_icmp(packet_t *pkt)
   if (get_packet_bytes((u_int8_t *) &icmp, pkt, 4) == 0)
     return;
 
-  if (my_args->m && !my_args->n)
+  if (my_args->m)
     {
       /* In minimal mode lets just dump the type and code */
       display_minimal_string("| ICMP ");
@@ -339,115 +342,114 @@ void dump_icmp(packet_t *pkt)
 	}
     }
   else
-    if (!my_args->n)
-      { 
-	/* announcement */
-	display_header_banner("ICMP Header");
-	
-	/* Dump the type */
-	sprintf(holder, "%d (%s)", icmp.type, 
-		map2str(icmp_type_map, icmp.type));
-	display("Type", (u_int8_t *) holder, strlen(holder), DISP_STRING);
-
-	/* 
-	 * Based on the type, dump the code, if the type has codes
-	 */
-	
-	switch(icmp.type)
-	  {
-	  case ICMP_TYPE_DESTUNREACHABLE:
-	    sprintf(holder, "%d (%s)", icmp.code, 
-		    map2str(icmp_du_map, icmp.code));
-	    display("Code", (u_int8_t *) &holder, strlen(holder), DISP_STRING);
-	    break;
-
-	  case ICMP_TYPE_TIMEEXCEEDED:
-	    sprintf(holder, "%d (%s)", icmp.code, 
-		    map2str(icmp_timeexceeded_map, icmp.code));
-	    display("Code", (u_int8_t *) &holder, strlen(holder), DISP_STRING);
-	    break;
-	    
-	  default:
-	    display("Code", (u_int8_t *) &icmp.code, 1, DISP_DEC);
-	    break;
-	  }
-	
-	icmp.checksum = ntohs(icmp.checksum);
-	display("Checksum", (u_int8_t *) &icmp.checksum, 2, DISP_DEC);
-  
-	/* 
-	 * Call an ICMP-type-specific function 
-	 */
-	
-	switch (icmp.type) 
-	  {
-	  case ICMP_TYPE_ECHOREPLY:
-	  case ICMP_TYPE_ECHOREQUEST:
-	    dump_icmp_echo(pkt);
-
-	    /* dump the hex buffer */
-	    hexbuffer_flush();
-
-	    return; /* bail so that we don't continue reading */
-	    
-	  case ICMP_TYPE_DESTUNREACHABLE:
-	    /* Get the unused bytes */
-	    if (get_packet_bytes((u_int8_t *) &holder, pkt, 4) == 0)
-	      return;
-	    break;
-
-	  case ICMP_TYPE_ROUTERSOLICIT:
-	    /* Get the unused bytes */
-	    if (get_packet_bytes((u_int8_t *) &holder, pkt, 4) == 0)
-	      return;
-	    /* dump the hex buffer */
-	    hexbuffer_flush();
-	    return;
+    {
+      /* announcement */
+      display_header_banner("ICMP Header");
+      
+      /* Dump the type */
+      sprintf(holder, "%d (%s)", icmp.type, 
+	      map2str(icmp_type_map, icmp.type));
+      display("Type", (u_int8_t *) holder, strlen(holder), DISP_STRING);
+      
+      /* 
+       * Based on the type, dump the code, if the type has codes
+       */
+      
+      switch(icmp.type)
+	{
+	case ICMP_TYPE_DESTUNREACHABLE:
+	  sprintf(holder, "%d (%s)", icmp.code, 
+		  map2str(icmp_du_map, icmp.code));
+	  display("Code", (u_int8_t *) &holder, strlen(holder), DISP_STRING);
+	  break;
 	  
-	  case ICMP_TYPE_ROUTERADVERT:
-	    dump_icmp_routeradvert(pkt);
-	    /* dump the hex buffer */
-	    hexbuffer_flush();
+	case ICMP_TYPE_TIMEEXCEEDED:
+	  sprintf(holder, "%d (%s)", icmp.code, 
+		  map2str(icmp_timeexceeded_map, icmp.code));
+	  display("Code", (u_int8_t *) &holder, strlen(holder), DISP_STRING);
+	  break;
+	  
+	default:
+	  display("Code", (u_int8_t *) &icmp.code, 1, DISP_DEC);
+	  break;
+	}
+      
+      icmp.checksum = ntohs(icmp.checksum);
+      display("Checksum", (u_int8_t *) &icmp.checksum, 2, DISP_DEC);
+      
+      /* 
+       * Call an ICMP-type-specific function 
+       */
+      
+      switch (icmp.type) 
+	{
+	case ICMP_TYPE_ECHOREPLY:
+	case ICMP_TYPE_ECHOREQUEST:
+	  dump_icmp_echo(pkt);
+	  
+	  /* dump the hex buffer */
+	  hexbuffer_flush();
+	  
+	  return; /* bail so that we don't continue reading */
+	  
+	case ICMP_TYPE_DESTUNREACHABLE:
+	  /* Get the unused bytes */
+	  if (get_packet_bytes((u_int8_t *) &holder, pkt, 4) == 0)
 	    return;
- 
-	  case ICMP_TYPE_SOURCEQUENCH:
-	  case ICMP_TYPE_REDIRECT:
-	  case ICMP_TYPE_PARAMPROBLEM:
-	  case ICMP_TYPE_TIMESTAMP:
-	  case ICMP_TYPE_TIMESTAMPREPLY:
-	  case ICMP_TYPE_INFOREQUEST:
-	  case ICMP_TYPE_INFOREPLY:
-	  case ICMP_TYPE_TRACEROUTE:
-	  case ICMP_TYPE_CONVERSIONERROR:
-	    break;
-
-	  case ICMP_TYPE_TIMEEXCEEDED:
-	    /* Get the unused bytes */
-	    if (get_packet_bytes((u_int8_t *) &holder, pkt, 4) == 0)
-	      return;
-	    break;
-	    
-	  case ICMP_TYPE_MASKREQUEST:
-	  case ICMP_TYPE_MASKREPLY:
-	    dump_icmp_mask(pkt);
-	    break;
-	    
-	  default:
-	    break;
-	    
-	  }
-	
-	/* dump the hex buffer */
-	hexbuffer_flush();
-
-	/*
-	 * In most ICMP packets there will be an IP header after the ICMP hdr.
-	 * If it seems to be there, we can parse it out
-	 */
-	
-	if (get_packet_bytesleft(pkt) >= 20)
-	  dump_ip(pkt);
-      }
-
+	  break;
+	  
+	case ICMP_TYPE_ROUTERSOLICIT:
+	  /* Get the unused bytes */
+	  if (get_packet_bytes((u_int8_t *) &holder, pkt, 4) == 0)
+	    return;
+	  /* dump the hex buffer */
+	  hexbuffer_flush();
+	  return;
+	  
+	case ICMP_TYPE_ROUTERADVERT:
+	  dump_icmp_routeradvert(pkt);
+	  /* dump the hex buffer */
+	  hexbuffer_flush();
+	  return;
+	  
+	case ICMP_TYPE_SOURCEQUENCH:
+	case ICMP_TYPE_REDIRECT:
+	case ICMP_TYPE_PARAMPROBLEM:
+	case ICMP_TYPE_TIMESTAMP:
+	case ICMP_TYPE_TIMESTAMPREPLY:
+	case ICMP_TYPE_INFOREQUEST:
+	case ICMP_TYPE_INFOREPLY:
+	case ICMP_TYPE_TRACEROUTE:
+	case ICMP_TYPE_CONVERSIONERROR:
+	  break;
+	  
+	case ICMP_TYPE_TIMEEXCEEDED:
+	  /* Get the unused bytes */
+	  if (get_packet_bytes((u_int8_t *) &holder, pkt, 4) == 0)
+	    return;
+	  break;
+	  
+	case ICMP_TYPE_MASKREQUEST:
+	case ICMP_TYPE_MASKREPLY:
+	  dump_icmp_mask(pkt);
+	  break;
+	  
+	default:
+	  break;
+	  
+	}
+      
+      /* dump the hex buffer */
+      hexbuffer_flush();
+      
+      /*
+       * In most ICMP packets there will be an IP header after the ICMP hdr.
+       * If it seems to be there, we can parse it out
+       */
+      
+      if (get_packet_bytesleft(pkt) >= 20)
+	dump_ip(pkt);
+    }
+  
 }
 
