@@ -5,7 +5,7 @@
 **
 ** Comments: Dump ICMPv6 information
 **
-** $Id: icmpv6.c,v 1.10 2001/04/02 17:41:01 mborella Exp $
+** $Id: icmpv6.c,v 1.11 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -81,6 +81,9 @@ void dump_icmpv6(packet_t *pkt)
   u_int16_t       ping6_id, ping6_seqno;
   u_int8_t        v6addr[16];
 
+  /* Set the layer */
+  set_layer(LAYER_NETWORK);
+
   /*
    * Stats accounting
    */
@@ -111,32 +114,31 @@ void dump_icmpv6(packet_t *pkt)
       display_minimal_string(" ");
     }
   else
-    if (!my_args->n)
-      {
-	/* announcement */
-	display_header_banner("ICMPv6 Header");
-	
-	/* print type */
-	sprintf(holder, "%d (%s)", icmpv6.type, 
-		map2str(icmpv6_type_map, icmpv6.type));
-	display_string("Type", holder);
-
-	/* based on the type, decide what to do with the code */
-	switch(icmpv6.type)
-	  {
-	  case ICMPV6_TYPE_DESTUNREACHABLE:
-	    sprintf(holder, "%d (%s)", icmpv6.code, 
-		map2str(icmpv6_ducode_map, icmpv6.code));
-	    display_string("Code", holder);
-	    break;
-	    
-	  default:
-	    display("Code", (u_int8_t *) &icmpv6.code, 1, DISP_DEC);
-	  }
+    {
+      /* announcement */
+      display_header_banner("ICMPv6 Header");
+      
+      /* print type */
+      sprintf(holder, "%d (%s)", icmpv6.type, 
+	      map2str(icmpv6_type_map, icmpv6.type));
+      display_string("Type", holder);
+      
+      /* based on the type, decide what to do with the code */
+      switch(icmpv6.type)
+	{
+	case ICMPV6_TYPE_DESTUNREACHABLE:
+	  sprintf(holder, "%d (%s)", icmpv6.code, 
+		  map2str(icmpv6_ducode_map, icmpv6.code));
+	  display_string("Code", holder);
+	  break;
 	  
-	display("Checksum", (u_int8_t *) &icmpv6.checksum, 2, DISP_DEC);
-      }
-
+	default:
+	  display("Code", (u_int8_t *) &icmpv6.code, 1, DISP_DEC);
+	}
+      
+      display("Checksum", (u_int8_t *) &icmpv6.checksum, 2, DISP_DEC);
+    }
+  
   /*
    * Special processing of the rest of the ICMP part
    */
@@ -202,22 +204,19 @@ void dump_icmpv6(packet_t *pkt)
       /* Next 16 bytes are an IPv6 address */
       if (get_packet_bytes((u_int8_t *) &v6addr, pkt, 16) == 0)
 	return;
-      if (!my_args->n)
+      if (my_args->m)
 	{
-	  if (my_args->m)
-	    {
-	      display_minimal_ipv6((u_int8_t *) &v6addr);
-	      display_minimal_string(" ");
-	    }
-	  else
-	    display_ipv6("Address", (u_int8_t *) &v6addr);
+	  display_minimal_ipv6((u_int8_t *) &v6addr);
+	  display_minimal_string(" ");
 	}
+      else
+	display_ipv6("Address", (u_int8_t *) &v6addr);
       break;
-
+      
     default:
       break;
     }
-
+  
 }
 
 
