@@ -5,7 +5,7 @@
 **
 ** Comments: Dump IP header information
 **
-** $Id: ip.c,v 1.19 2001/04/02 17:41:01 mborella Exp $
+** $Id: ip.c,v 1.21 2001/05/28 19:51:31 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -74,6 +74,9 @@ void dump_ip(packet_t *pkt)
   printf("\nEntering IP\n");
 #endif
 
+  /* Set the layer */
+  set_layer(LAYER_NETWORK);
+
   /*
    * Stats accounting
    */
@@ -84,7 +87,7 @@ void dump_ip(packet_t *pkt)
    * Get the IP header
    */
 
-  if (get_packet_bytes((u_int8_t *) &ip, pkt, 20) == 0)
+  if (get_packet_bytes((u_int8_t *) &ip, pkt, sizeof(ip_header_t)) == 0)
     return;
 
   /*
@@ -102,11 +105,20 @@ void dump_ip(packet_t *pkt)
   mf_bit = (ip.offset & 0x2000) >> 13;
   ip.checksum = ntohs(ip.checksum);
 
+  /*
+   * Set the effective end of the packet.  Take the total length as per the 
+   * IP header, subtract the header we've read.  This is the number of bytes
+   * into the packet where the end should be.  This helps us get rid of 
+   * link layer padding on tinygrams.
+   */
+
+  set_packet_end(pkt, ip.length - sizeof(ip_header_t));
+
   /*
    * Dump header
    */
 
-  if (my_args->m && !my_args->n)
+  if (my_args->m)
     {
       u_int16_t new_fo = frag_off * 8;
  
@@ -127,41 +139,40 @@ void dump_ip(packet_t *pkt)
       display_minimal_string(") ");
     }
   else
-    if (!my_args->n)
-      {
-	u_int8_t holder[64];
-
-	/* announcement */
-	display_header_banner("IP Header");
-	
-	/* print fields */
-	display("Version", (u_int8_t *) &ver, 1, DISP_DEC);
-	sprintf(holder, "%d (%d bytes)", hlen, hlen*4);	
-	display_string("Header length", holder);
-	display("TOS", (u_int8_t *) &ip.tos, 1, DISP_HEX);
-	display("Total length", (u_int8_t *) &ip.length, 2, DISP_DEC);
-	display("Identification", (u_int8_t *) &ip.id, 2, DISP_DEC);
-
-	if (frag_off)
-	  {
-	    sprintf(holder, "%d (%d bytes)", frag_off, frag_off*8);
-	    display_string("Fragmentation offset", holder);
-	  }
-	else
-	  display("Fragmentation offset", (u_int8_t *) &frag_off, 2, DISP_DEC);
-
-	display("Unused bit", (u_int8_t *) &u_bit, 1, DISP_BINNLZ);
-	display("Don't fragment bit", (u_int8_t *) &df_bit, 1, DISP_BINNLZ);
-	display("More fragments bit", (u_int8_t *) &mf_bit, 1, DISP_BINNLZ);
-	display("Time to live", (u_int8_t *) &ip.ttl, 1, DISP_DEC);
-	display_strmap("Protocol", ip.protocol, ipproto_map);
-	display("Header checksum", (u_int8_t *) &ip.checksum, 2, 
-		DISP_DEC);
+    {
+      u_int8_t holder[64];
       
-	/* IP's are not in network byte order?? */
-	display_ipv4("Source address", (u_int8_t *) &ip.src); 
-	display_ipv4("Destination address", (u_int8_t *) &ip.dst); 
-      }
+      /* announcement */
+      display_header_banner("IP Header");
+      
+      /* print fields */
+      display("Version", (u_int8_t *) &ver, 1, DISP_DEC);
+      sprintf(holder, "%d (%d bytes)", hlen, hlen*4);	
+      display_string("Header length", holder);
+      display("TOS", (u_int8_t *) &ip.tos, 1, DISP_HEX);
+      display("Total length", (u_int8_t *) &ip.length, 2, DISP_DEC);
+      display("Identification", (u_int8_t *) &ip.id, 2, DISP_DEC);
+      
+      if (frag_off)
+	{
+	  sprintf(holder, "%d (%d bytes)", frag_off, frag_off*8);
+	  display_string("Fragmentation offset", holder);
+	}
+      else
+	display("Fragmentation offset", (u_int8_t *) &frag_off, 2, DISP_DEC);
+      
+      display("Unused bit", (u_int8_t *) &u_bit, 1, DISP_BINNLZ);
+      display("Don't fragment bit", (u_int8_t *) &df_bit, 1, DISP_BINNLZ);
+      display("More fragments bit", (u_int8_t *) &mf_bit, 1, DISP_BINNLZ);
+      display("Time to live", (u_int8_t *) &ip.ttl, 1, DISP_DEC);
+      display_strmap("Protocol", ip.protocol, ipproto_map);
+      display("Header checksum", (u_int8_t *) &ip.checksum, 2, 
+	      DISP_DEC);
+      
+      /* IP's are not in network byte order?? */
+      display_ipv4("Source address", (u_int8_t *) &ip.src); 
+      display_ipv4("Destination address", (u_int8_t *) &ip.dst); 
+    }
 
   /*
    * Check for IP options
@@ -171,8 +182,7 @@ void dump_ip(packet_t *pkt)
     dump_ip_options(pkt, hlen * 4 - 20);
 
   /* dump the hex buffer */
-  if (!my_args->n)
-    hexbuffer_flush();
+  hexbuffer_flush();
   
   /*
    * If this is fragment zero, hand it to the next higher
@@ -220,15 +230,12 @@ void dump_ip_options(packet_t *pkt, u_int8_t length)
       sprintf(holder, "%d (%s)", opt.code, 
 	      map2str(ip_option_map, opt.code));
       
-      if (!my_args->n)
+      if (!my_args->m)
+	display_string("IP option code", holder);
+      else
 	{
-	  if (!my_args->m)
-	    display_string("IP option code", holder);
-	  else
-	    {
-	      display_minimal_string(holder);
-	      display_minimal_string(" ");
-	    }
+	  display_minimal_string(holder);
+	  display_minimal_string(" ");
 	}
       
       /*
@@ -245,7 +252,7 @@ void dump_ip_options(packet_t *pkt, u_int8_t length)
       if (get_packet_bytes((u_int8_t *) &opt.length, pkt, 1) == 0)
 	return;
       bytes_read += 1;
-      if (!my_args->m && !my_args->n)
+      if (!my_args->m)
 	display("  Length", (u_int8_t *) &opt.length, 1, DISP_DEC);
 
       /*
