@@ -5,7 +5,7 @@
 **
 ** Comments: 
 **
-** $Id: mobileip.c,v 1.8 2001/04/26 23:49:50 mborella Exp $
+** $Id: mobileip.c,v 1.9 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -469,6 +469,9 @@ void dump_mobileip(packet_t *pkt)
 {
   u_int8_t          first_byte;
 
+  /* Set the layer */
+  set_layer(LAYER_APPLICATION);
+
   /*
    * Look at the first byte to determine the type
    */
