@@ -5,7 +5,7 @@
 **
 ** Comments: Dump OSPF information
 **
-** $Id: ospf.c,v 1.10 2001/04/02 17:41:01 mborella Exp $
+** $Id: ospf.c,v 1.11 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -87,26 +87,25 @@ void dump_ospf_hello(packet_t *pkt, u_int16_t length)
    * Dump the fields 
    */
   
-  if (my_args->m && !my_args->n)
+  if (my_args->m)
     {
       display_minimal_ipv4((u_int8_t *) &ospf_hello.designated_router);
       display_minimal_string(" ");
     }
   else
-    if (!my_args->n)
-      { 
-	display_ipv4("Netmask", (u_int8_t *) &ospf_hello.netmask);
-	display("Interval", (u_int8_t *) &ospf_hello.interval, 2, 
-		DISP_DEC);
-	display("Options", (u_int8_t *) &ospf_hello.options, 1, DISP_HEX);
-	display("Router priority", (u_int8_t *) &ospf_hello.router_priority, 
-		1, DISP_DEC);
-	display("Dead interval", (u_int8_t *) &ospf_hello.dead_interval, 4, 
-		DISP_DEC);
-	display_ipv4("Designated router", 
-		(u_int8_t *) &ospf_hello.designated_router);
-	display_ipv4("Backup router", (u_int8_t *) &ospf_hello.backup_router);
-      }
+    { 
+      display_ipv4("Netmask", (u_int8_t *) &ospf_hello.netmask);
+      display("Interval", (u_int8_t *) &ospf_hello.interval, 2, 
+	      DISP_DEC);
+      display("Options", (u_int8_t *) &ospf_hello.options, 1, DISP_HEX);
+      display("Router priority", (u_int8_t *) &ospf_hello.router_priority, 
+	      1, DISP_DEC);
+      display("Dead interval", (u_int8_t *) &ospf_hello.dead_interval, 4, 
+	      DISP_DEC);
+      display_ipv4("Designated router", 
+		   (u_int8_t *) &ospf_hello.designated_router);
+      display_ipv4("Backup router", (u_int8_t *) &ospf_hello.backup_router);
+    }
 
   /*
    * Dump the neighbors, which should just be a bunch of IP addresses
@@ -118,16 +117,13 @@ void dump_ospf_hello(packet_t *pkt, u_int16_t length)
       if (get_packet_bytes((u_int8_t *) &neighbor, pkt, 4) == 0)
 	return;
 
-      if (!my_args->n)
+      if (my_args->m)
 	{
-	  if (my_args->m)
-	    {
-	      display_minimal_ipv4((u_int8_t *) &neighbor);
-	      display_minimal_string(" ");
-	    }
-	  else
-	    display_ipv4("Neighbor", (u_int8_t *) &neighbor);
+	  display_minimal_ipv4((u_int8_t *) &neighbor);
+	  display_minimal_string(" ");
 	}
+      else
+	display_ipv4("Neighbor", (u_int8_t *) &neighbor);
     }
 }
 
@@ -145,6 +141,9 @@ void dump_ospf(packet_t *pkt)
   ospf_common_header_t ospf;
   char holder[64];
   
+  /* Set the layer */
+  set_layer(LAYER_APPLICATION);
+
   /*
    * Stats accounting
    */
@@ -171,7 +170,7 @@ void dump_ospf(packet_t *pkt)
    * Dump the fields 
    */
   
-  if (my_args->m && !my_args->n)
+  if (my_args->m)
     {
       /* In minimal mode lets just dump the type and the router ID */
       display_minimal_string("| OSPF ");
@@ -181,30 +180,29 @@ void dump_ospf(packet_t *pkt)
       display_minimal_string(" ");      
     }
   else
-    if (!my_args->n)
-      { 
-	/* announcement */
-	display_header_banner("OSPF Header");
-
-	display("Version", (u_int8_t *) &ospf.version, 1, DISP_DEC);
-	sprintf(holder, "%d (%s)", ospf.type, 
-		map2str(ospf_type_map, ospf.type));
-	display_string("Type", holder);
-	display("Length", (u_int8_t *) &ospf.length, 2, DISP_DEC);
-	display_ipv4("Router ID", (u_int8_t *) &ospf.router_id);
-	display_ipv4("Area ID", (u_int8_t *) &ospf.area_id);
-	display("Checksum", (u_int8_t *) &ospf.checksum, 2, DISP_DEC);
-	sprintf(holder, "%d (%s)", ospf.auth_type, 
-		map2str(ospf_auth_map, ospf.auth_type));
-	display_string("Authentication", holder);
-	display("Authentication data", (u_int8_t *) &ospf.auth_data, 8, 
-		DISP_HEX);
-      }
+    { 
+      /* announcement */
+      display_header_banner("OSPF Header");
+      
+      display("Version", (u_int8_t *) &ospf.version, 1, DISP_DEC);
+      sprintf(holder, "%d (%s)", ospf.type, 
+	      map2str(ospf_type_map, ospf.type));
+      display_string("Type", holder);
+      display("Length", (u_int8_t *) &ospf.length, 2, DISP_DEC);
+      display_ipv4("Router ID", (u_int8_t *) &ospf.router_id);
+      display_ipv4("Area ID", (u_int8_t *) &ospf.area_id);
+      display("Checksum", (u_int8_t *) &ospf.checksum, 2, DISP_DEC);
+      sprintf(holder, "%d (%s)", ospf.auth_type, 
+	      map2str(ospf_auth_map, ospf.auth_type));
+      display_string("Authentication", holder);
+      display("Authentication data", (u_int8_t *) &ospf.auth_data, 8, 
+	      DISP_HEX);
+    }
 
   /*
    * Dump the more specific header type XXX NOT COMPLETE!
    */
-
+  
   switch(ospf.type)
     {
     case OSPF_TYPE_HELLO:
