@@ -5,7 +5,7 @@
 **
 ** Comments: Packet manipulation routines
 **
-** $Id: packet_manip.c,v 1.11 2001/05/18 15:30:53 mborella Exp $
+** $Id: packet_manip.c,v 1.13 2001/05/28 19:51:31 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -116,6 +116,7 @@ inline int get_packet_line(u_int8_t *dst, u_int32_t max, packet_t *p)
 
   memcpy(dst, p->current, ptr - p->current);
   dst[ptr - p->current] = '\0';
+  hexbuffer_add(p->current, ptr - p->current);
 
   /* 
    * Increment the current pointer past the \n
@@ -256,3 +257,22 @@ inline int32_t get_packet_markdistance(packet_t *pkt)
 
   return pkt->current - pkt->mark;
 }
+
+/*----------------------------------------------------------------------------
+**
+** set_packet_end()
+**
+** Set the end of the packet to be the given number of bytes beyond the 
+** current pointer.
+**
+**----------------------------------------------------------------------------
+*/
+
+inline void set_packet_end(packet_t * pkt, int n)
+{
+  /* make sure we're not running off the packet */
+  if (pkt->current + n >= pkt->end)
+    return;
+
+  pkt->end = pkt->current + n;
+}
