@@ -2,8 +2,8 @@
 **
 ** parse_cl.c
 **
-** Mon Apr  2 14:48:36 2001
-** Linux 2.2.15 (#7 Wed Aug 30 18:54:13 CDT 2000) i686
+** Mon May 28 14:27:48 2001
+** Linux 2.4.2 (#5 Thu Apr 26 12:29:16 CDT 2001) i686
 ** mborella@stratos (Mike Borella)
 **
 ** C file for command line parser
@@ -31,7 +31,13 @@
 
 void usage(char *executable)
 {
-  printf("usage: %s [ -bcilmnPprTtwxhv ] \n", executable);
+  printf("usage: %s [ -abcilmnPprTtwxhv ] \n", executable);
+  printf("  [ -a ] ");
+  printf("(");
+  printf("type=");
+  printf("FLAG");
+  printf(")\n");
+  printf("         Don't print application layer data\n");
   printf("  [ -b ] ");
   printf("(");
   printf("type=");
@@ -167,6 +173,7 @@ struct arg_t *Cmdline(int argc, char *argv[])
 
   static struct option long_options[] =
   {
+    {"", 0, 0, 'a'},
     {"", 0, 0, 'b'},
     {"count", 1, 0, 'c'},
     {"interface", 1, 0, 'i'},
@@ -187,6 +194,7 @@ struct arg_t *Cmdline(int argc, char *argv[])
 
   my_args = (struct arg_t *) malloc (sizeof(struct arg_t));
 
+  my_args->a = false;
   my_args->b = false;
   my_args->i = NULL;
   my_args->l = false;
@@ -202,10 +210,14 @@ struct arg_t *Cmdline(int argc, char *argv[])
   my_args->h = false;
   my_args->v = false;
 
-  while ((c = getopt_long(argc, argv, "bc:i:lmnP:pr:Ttw:xhv", long_options, &option_index)) != EOF)
+  while ((c = getopt_long(argc, argv, "abc:i:lmnP:pr:Ttw:xhv", long_options, &option_index)) != EOF)
     {
       switch(c)
         {
+        case 'a': 
+          my_args->a = true;
+          break;
+
         case 'b': 
           my_args->b = true;
           break;
