@@ -2,8 +2,8 @@
 **
 ** parse_cl.h
 **
-** Mon Apr  2 14:48:36 2001
-** Linux 2.2.15 (#7 Wed Aug 30 18:54:13 CDT 2000) i686
+** Mon May 28 14:27:48 2001
+** Linux 2.4.2 (#5 Thu Apr 26 12:29:16 CDT 2001) i686
 ** mborella@stratos (Mike Borella)
 **
 ** Header file for command line parser
@@ -26,6 +26,7 @@ typedef enum bool_t
 /* customized structure for command line parameters */
 struct arg_t
 {
+  bool a;
   bool b;
   int c;
   char * i;
