@@ -5,7 +5,7 @@
 **
 ** Comments: Dump packet payload
 **
-** $Id: payload.c,v 1.5 2001/04/26 23:49:50 mborella Exp $
+** $Id: payload.c,v 1.6 2001/05/28 20:09:11 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -49,6 +49,9 @@ void dump_payload(packet_t *pkt)
   char * buf_end;
   int    bytes;
 
+  /* Set the layer */
+  set_layer(LAYER_APPLICATION);
+
   /* display announcement */
   display_header_banner("Payload");
 
@@ -84,7 +87,8 @@ void dump_payload(packet_t *pkt)
 	      buf_ptr++;
             }
 	}
-      printf("%-48s %s\n",hexbuf,charbuf);
+      if (!check_layer())
+	printf("%-48s %s\n",hexbuf,charbuf);
     }
   while(buf_ptr < buf_end);
 }
