@@ -7,7 +7,7 @@
 ** NOTE: I am relying on the ucd snmp library for much of the heavy 
 ** lifting
 **
-** $Id: snmp.c,v 1.8 2001/03/27 20:45:36 mborella Exp $
+** $Id: snmp.c,v 1.9 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -91,6 +91,9 @@ dump_snmp(packet_t *pkt)
 	int               snmpver   = -1;
 	u_int32_t         nbytes;
 
+  /* Set the layer */
+  set_layer(LAYER_APPLICATION);
+
 	/* get all of the remaining data from the packet so that we can
 	 * pass it on to the asn parse api */
 
