@@ -14,7 +14,7 @@
 ** it is version 1 or 2.  So I'm not sure what else we can do with this 
 ** module, but this simple parser is at least a start.
 **
-** $Id: ssh.c,v 1.4 2000/11/07 19:46:09 mborella Exp $
+** $Id: ssh.c,v 1.5 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -56,6 +56,9 @@ void dump_ssh(packet_t *pkt)
    * damn thing and work from there...
    */
 
+  /* Set the layer */
+  set_layer(LAYER_APPLICATION);
+
   /* find the paylaod size, then allocate memory and read the packet */
   size = get_packet_bytesleft(pkt);
   if (size <= 0)
