@@ -6,7 +6,7 @@
 **
 ** Comments: Dump TCP header information. 
 **
-** $Id: tcp.c,v 1.19 2001/05/18 15:30:53 mborella Exp $
+** $Id: tcp.c,v 1.20 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -82,7 +82,7 @@ void dump_tcp_options(packet_t *pkt, u_int8_t length)
       /* take care of the 1-byte options */
       if (kind == TCP_OPTION_EOL || kind == TCP_OPTION_NOP)
 	{
-	  if (!my_args->m && !my_args->t)
+	  if (!my_args->m)
 	    {
 	      sprintf(holder, "%d (%s)", kind, 
 		      map2str(tcp_option_map, kind));
@@ -92,25 +92,22 @@ void dump_tcp_options(packet_t *pkt, u_int8_t length)
 	}
 
       /* display the option's name */
-      if (!my_args->t)
+      if (!my_args->m)
 	{
-	  if (!my_args->m)
-	    {
-	      sprintf(holder, "%d (%s)", kind, 
-		      map2str(tcp_option_map, kind));
-	      display_string("Option", holder);
-	    }
-	  else 
-	    {
-	      display_minimal_string("<");	  
-	      display_minimal_string(map2str(tcp_option_map, kind));
-	    }
+	  sprintf(holder, "%d (%s)", kind, 
+		  map2str(tcp_option_map, kind));
+	  display_string("Option", holder);
 	}
-      
+      else 
+	{
+	  display_minimal_string("<");	  
+	  display_minimal_string(map2str(tcp_option_map, kind));
+	}
+          
       /* get and display the length field */
       if (get_packet_bytes((u_int8_t *) &option_length, pkt, 1) == 0)
 	return;
-      if (!my_args->m && !my_args->t)
+      if (!my_args->m)
 	display("  Length", (u_int8_t *) &option_length, 1, DISP_DEC);
       option_bytes_read += 1;
 
@@ -130,30 +127,24 @@ void dump_tcp_options(packet_t *pkt, u_int8_t length)
 	case TCP_OPTION_MSS:
 	  memcpy((void *) &mss, holder, 2);
 	  mss = ntohs(mss);
-	  if (!my_args->t)
+	  if (!my_args->m)
+	    display("  MSS", (u_int8_t *) &mss, 2, DISP_DEC);
+	  else
 	    {
-	      if (!my_args->m)
-		display("  MSS", (u_int8_t *) &mss, 2, DISP_DEC);
-	      else
-		{
-		  display_minimal_string(" ");
-		  display_minimal((u_int8_t *) &mss, 2, DISP_DEC);
-		  display_minimal_string(">");
-		}
+	      display_minimal_string(" ");
+	      display_minimal((u_int8_t *) &mss, 2, DISP_DEC);
+	      display_minimal_string(">");
 	    }
 	  break;
 	  
 	case TCP_OPTION_WS:
-	  if (!my_args->t)
+	  if (!my_args->m)
+	    display("  Shift count", (u_int8_t *) holder, 1, DISP_DEC);
+	  else
 	    {
-	      if (!my_args->m)
-		display("  Shift count", (u_int8_t *) holder, 1, DISP_DEC);
-	      else
-		{
-		  display_minimal_string(" ");
-		  display_minimal((u_int8_t *) holder, 1, DISP_DEC);
-		  display_minimal_string(">");
-		}
+	      display_minimal_string(" ");
+	      display_minimal((u_int8_t *) holder, 1, DISP_DEC);
+	      display_minimal_string(">");
 	    }
 	  break;
 
@@ -162,23 +153,20 @@ void dump_tcp_options(packet_t *pkt, u_int8_t length)
 	  ts1 = ntohl(ts1);
 	  memcpy((void *) &ts2, holder+4, 4);
 	  ts2 = ntohl(ts2);
-	  if (!my_args->t)
+	  if (!my_args->m)
 	    {
-	      if (!my_args->m)
-		{
-		  display("  Timestamp value", (u_int8_t *) &ts1, 4, 
-			  DISP_DEC);
-		  display("  Timestamp reply", (u_int8_t *) &ts2, 4, 
-			  DISP_DEC);
-		}
-	      else
-		{
-		  display_minimal_string(" ");
-		  display_minimal((u_int8_t *) &ts1, 4, DISP_DEC);
-		  display_minimal_string(" ");
-		  display_minimal((u_int8_t *) &ts2, 4, DISP_DEC);
-		  display_minimal_string(">");
-		}
+	      display("  Timestamp value", (u_int8_t *) &ts1, 4, 
+		      DISP_DEC);
+	      display("  Timestamp reply", (u_int8_t *) &ts2, 4, 
+		      DISP_DEC);
+	    }
+	  else
+	    {
+	      display_minimal_string(" ");
+	      display_minimal((u_int8_t *) &ts1, 4, DISP_DEC);
+	      display_minimal_string(" ");
+	      display_minimal((u_int8_t *) &ts2, 4, DISP_DEC);
+	      display_minimal_string(">");
 	    }
 	  break;
 
@@ -193,7 +181,7 @@ void dump_tcp_options(packet_t *pkt, u_int8_t length)
 	  */
 
 	default:
-	  if (my_args->m && !my_args->t)
+	  if (my_args->m)
 	    display_minimal_string(">");
 	  break;
 
@@ -204,7 +192,7 @@ void dump_tcp_options(packet_t *pkt, u_int8_t length)
    * Trailing space for minimal mode
    */
 
-  if (my_args->m && !my_args->t)
+  if (my_args->m)
     display_minimal_string(" ");
 
 #ifdef DEBUG
@@ -228,11 +216,15 @@ void dump_tcp(packet_t *pkt)
   u_int8_t hlen, unused;
   char flag_str[8];
   service_func_t app;
+  char holder[64];
 
 #ifdef DEBUG
   printf("\nEntering TCP\n");
 #endif
 
+  /* Set the layer */
+  set_layer(LAYER_TRANSPORT);
+
   /*
    * Stats accounting
    */
@@ -299,34 +291,34 @@ void dump_tcp(packet_t *pkt)
       display_minimal_string(") ");
     }
   else
-    if (!my_args->t)
-      {
-	/* Dump TCP header announcement */
-	display_header_banner("TCP Header");
-	
-	/* port fields */
-	display_strmap("Source port", tcp.src, port_map);
-	display_strmap("Destination port", tcp.dst, port_map);
-	
-	/* sequence and acknowledgement */
-	display("Sequence number", (u_int8_t *) &tcp.seq_number, 4, 
-		DISP_DEC);
-	display("Acknowledgement number", (u_int8_t *) &tcp.ack_number, 4, 
-		DISP_DEC);
-	
-	/* header length and unused bits */
-	display("Header length", (u_int8_t *) &hlen, 1, DISP_DEC);
-	display("Unused", (u_int8_t *) &unused, 1, DISP_DEC);
-	
-	/* flags */
-	display("Flags", (u_int8_t *) &flag_str, strlen(flag_str), 
-		DISP_STRING);
-	
-	/* window size, checksum and urgent ptr */
-	display("Window size", (u_int8_t *) &tcp.window, 2, DISP_DEC);
-	display("Checksum", (u_int8_t *) &tcp.checksum, 2, DISP_DEC);
-	display("Urgent", (u_int8_t *) &tcp.urgent, 2, DISP_DEC);
-      }
+    {
+      /* Dump TCP header announcement */
+      display_header_banner("TCP Header");
+      
+      /* port fields */
+      display_strmap("Source port", tcp.src, port_map);
+      display_strmap("Destination port", tcp.dst, port_map);
+      
+      /* sequence and acknowledgement */
+      display("Sequence number", (u_int8_t *) &tcp.seq_number, 4, 
+	      DISP_DEC);
+      display("Acknowledgement number", (u_int8_t *) &tcp.ack_number, 4, 
+	      DISP_DEC);
+      
+      /* header length and unused bits */
+      sprintf(holder, "%d (%d bytes)", hlen, hlen*4);   
+      display_string("Header length", holder);
+      display("Unused", (u_int8_t *) &unused, 1, DISP_DEC);
+      
+      /* flags */
+      display("Flags", (u_int8_t *) &flag_str, strlen(flag_str), 
+	      DISP_STRING);
+      
+      /* window size, checksum and urgent ptr */
+      display("Window size", (u_int8_t *) &tcp.window, 2, DISP_DEC);
+      display("Checksum", (u_int8_t *) &tcp.checksum, 2, DISP_DEC);
+      display("Urgent", (u_int8_t *) &tcp.urgent, 2, DISP_DEC);
+    }
   
   
   /*
@@ -335,11 +327,10 @@ void dump_tcp(packet_t *pkt)
    */
 
   if (hlen > 5)
-      dump_tcp_options(pkt, hlen*4 - 20);
+    dump_tcp_options(pkt, hlen*4 - 20);
 
   /* dump the hex buffer */
-  if (!my_args->t)
-    hexbuffer_flush();
+  hexbuffer_flush();
 
   /*
    * If there is something left of the packet, process the application
